/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */
#ifndef __GdomDOMWindow_H__
#define __GdomDOMWindow_H__
#include <webkit/webkitdefines.h>
#include "gdom/GdomCSSRuleList.h"
#include "gdom/GdomCSSStyleDeclaration.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomDOMSelection.h"
#include "gdom/GdomDatabase.h"
#include "gdom/GdomElement.h"
#include "glib-object.h"


G_BEGIN_DECLS

typedef struct _GdomDOMWindow GdomDOMWindow;
typedef struct _GdomDOMWindowClass GdomDOMWindowClass;


#define GDOM_TYPE_DOM_WINDOW            (gdom_dom_window_get_type())
#define GDOM_DOM_WINDOW(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), GDOM_TYPE_DOM_WINDOW, GdomDOMWindow))
#define GDOM_DOM_WINDOW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  GDOM_TYPE_DOM_WINDOW, GdomDOMWindow)Class)
#define GDOM_IS_DOM_WINDOW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), GDOM_TYPE_DOM_WINDOW))
#define GDOM_IS_DOM_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  GDOM_TYPE_DOM_WINDOW))
#define GDOM_DOM_WINDOW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  GDOM_TYPE_DOM_WINDOW, GdomDOMWindowClass))

typedef struct _GdomDOMWindowPrivate GdomDOMWindowPrivate;

struct _GdomDOMWindow {
    GdomDOMObject parent_instance;
    GdomDOMWindowPrivate *priv;
};

struct _GdomDOMWindowClass {
    GObjectClass parent_class;
};

WEBKIT_API GType
gdom_dom_window_get_type (void);

WEBKIT_API GdomDOMSelection *
gdom_dom_window_get_selection (GdomDOMWindow *thiz);

WEBKIT_API void
gdom_dom_window_focus (GdomDOMWindow *thiz);

WEBKIT_API void
gdom_dom_window_blur (GdomDOMWindow *thiz);

WEBKIT_API void
gdom_dom_window_close (GdomDOMWindow *thiz);

WEBKIT_API void
gdom_dom_window_print (GdomDOMWindow *thiz);

WEBKIT_API void
gdom_dom_window_stop (GdomDOMWindow *thiz);

WEBKIT_API void
gdom_dom_window_alert (GdomDOMWindow *thiz, gchar * message);

WEBKIT_API gboolean
gdom_dom_window_confirm (GdomDOMWindow *thiz, gchar * message);

WEBKIT_API gchar *
gdom_dom_window_prompt (GdomDOMWindow *thiz, gchar * message, gchar * default_value);

WEBKIT_API gboolean
gdom_dom_window_find (GdomDOMWindow *thiz, gchar * string, gboolean case_sensitive, gboolean backwards, gboolean wrap, gboolean whole_word, gboolean search_in_frames, gboolean show_dialog);

WEBKIT_API void
gdom_dom_window_scroll_by (GdomDOMWindow *thiz, glong x, glong y);

WEBKIT_API void
gdom_dom_window_scroll_to (GdomDOMWindow *thiz, glong x, glong y);

WEBKIT_API void
gdom_dom_window_scroll (GdomDOMWindow *thiz, glong x, glong y);

WEBKIT_API void
gdom_dom_window_move_by (GdomDOMWindow *thiz, gfloat x, gfloat y);

WEBKIT_API void
gdom_dom_window_move_to (GdomDOMWindow *thiz, gfloat x, gfloat y);

WEBKIT_API void
gdom_dom_window_resize_by (GdomDOMWindow *thiz, gfloat x, gfloat y);

WEBKIT_API void
gdom_dom_window_resize_to (GdomDOMWindow *thiz, gfloat width, gfloat height);

WEBKIT_API GdomCSSStyleDeclaration *
gdom_dom_window_get_computed_style (GdomDOMWindow *thiz, GdomElement * element, gchar * pseudo_element);

WEBKIT_API GdomCSSRuleList *
gdom_dom_window_get_matched_css_rules (GdomDOMWindow *thiz, GdomElement * element, gchar * pseudo_element, gboolean author_only);

WEBKIT_API GdomDatabase *
gdom_dom_window_open_database (GdomDOMWindow *thiz, gchar * name, gchar * version, gchar * display_name, gulong estimated_size);


/* XXX TODO: custom function gdom_dom_window_post_message */

G_END_DECLS

#endif /* __GdomDOMWindow_H__ */
